# Espalier
Espalier reconciles discordant trees and reconcstructs ARGs using maximum agreement forests.

For more information on the algorithms behind Espalier please see:
Rasmussen, D.A. and Guo, F. Espalier: Efficient tree reconciliation and ARG reconstruction using maximum agreement forests. (in prep).

## Installation and set up

Currently adding ability to install Espalier through PyPI. 
